pub struct RequestBuilder { /* private fields */ }Trait Implementations
Sourceimpl Debug for RequestBuilder
impl Debug for RequestBuilder
Sourceimpl FromValue for RequestBuilder
impl FromValue for RequestBuilder
Sourcefn from_value(value: ValuePtr, vm: &mut Vm) -> Result<Self, StackError>
fn from_value(value: ValuePtr, vm: &mut Vm) -> Result<Self, StackError>
Try to convert to the given type, from the given value.
Sourceimpl<'a> ReflectValueType for &'a RequestBuilder
impl<'a> ReflectValueType for &'a RequestBuilder
Sourcefn value_type() -> ValueType
fn value_type() -> ValueType
Convert into a value type.
Sourcefn value_type_info() -> ValueTypeInfo
fn value_type_info() -> ValueTypeInfo
Access diagnostical information on the value type.
Sourceimpl<'a> ReflectValueType for &'a mut RequestBuilder
impl<'a> ReflectValueType for &'a mut RequestBuilder
Sourcefn value_type() -> ValueType
fn value_type() -> ValueType
Convert into a value type.
Sourcefn value_type_info() -> ValueTypeInfo
fn value_type_info() -> ValueTypeInfo
Access diagnostical information on the value type.
Sourceimpl ReflectValueType for RequestBuilder
impl ReflectValueType for RequestBuilder
Sourcefn value_type() -> ValueType
fn value_type() -> ValueType
Convert into a value type.
Sourcefn value_type_info() -> ValueTypeInfo
fn value_type_info() -> ValueTypeInfo
Access diagnostical information on the value type.
Sourceimpl ToValue for RequestBuilder
impl ToValue for RequestBuilder
Sourceimpl<'a> UnsafeFromValue for &'a RequestBuilder
impl<'a> UnsafeFromValue for &'a RequestBuilder
Sourcetype Guard = RawRefGuard
type Guard = RawRefGuard
The raw guard returned. Read more
Sourceunsafe fn unsafe_from_value(
value: ValuePtr,
vm: &mut Vm,
) -> Result<(Self, Self::Guard), StackError>
unsafe fn unsafe_from_value( value: ValuePtr, vm: &mut Vm, ) -> Result<(Self, Self::Guard), StackError>
Convert the given reference using unsafe assumptions to a value. Read more
Sourceimpl<'a> UnsafeFromValue for &'a mut RequestBuilder
impl<'a> UnsafeFromValue for &'a mut RequestBuilder
Sourcetype Guard = RawMutGuard
type Guard = RawMutGuard
The raw guard returned. Read more
Sourceunsafe fn unsafe_from_value(
value: ValuePtr,
vm: &mut Vm,
) -> Result<(Self, Self::Guard), StackError>
unsafe fn unsafe_from_value( value: ValuePtr, vm: &mut Vm, ) -> Result<(Self, Self::Guard), StackError>
Convert the given reference using unsafe assumptions to a value. Read more
Sourceimpl<'a> UnsafeToValue for &'a RequestBuilder
impl<'a> UnsafeToValue for &'a RequestBuilder
Sourceunsafe fn unsafe_to_value(self, vm: &mut Vm) -> Result<ValuePtr, StackError>
unsafe fn unsafe_to_value(self, vm: &mut Vm) -> Result<ValuePtr, StackError>
Convert into a value.
Sourceimpl<'a> UnsafeToValue for &'a mut RequestBuilder
impl<'a> UnsafeToValue for &'a mut RequestBuilder
Sourceunsafe fn unsafe_to_value(self, vm: &mut Vm) -> Result<ValuePtr, StackError>
unsafe fn unsafe_to_value(self, vm: &mut Vm) -> Result<ValuePtr, StackError>
Convert into a value.