pub struct Response { /* private fields */ }Trait Implementations
Sourceimpl FromValue for Response
impl FromValue for Response
Sourcefn from_value(value: ValuePtr, vm: &mut Vm) -> Result<Self, StackError>
fn from_value(value: ValuePtr, vm: &mut Vm) -> Result<Self, StackError>
Try to convert to the given type, from the given value.
Sourceimpl<'a> ReflectValueType for &'a Response
impl<'a> ReflectValueType for &'a Response
Sourcefn value_type() -> ValueType
fn value_type() -> ValueType
Convert into a value type.
Sourcefn value_type_info() -> ValueTypeInfo
fn value_type_info() -> ValueTypeInfo
Access diagnostical information on the value type.
Sourceimpl<'a> ReflectValueType for &'a mut Response
impl<'a> ReflectValueType for &'a mut Response
Sourcefn value_type() -> ValueType
fn value_type() -> ValueType
Convert into a value type.
Sourcefn value_type_info() -> ValueTypeInfo
fn value_type_info() -> ValueTypeInfo
Access diagnostical information on the value type.
Sourceimpl ReflectValueType for Response
impl ReflectValueType for Response
Sourcefn value_type() -> ValueType
fn value_type() -> ValueType
Convert into a value type.
Sourcefn value_type_info() -> ValueTypeInfo
fn value_type_info() -> ValueTypeInfo
Access diagnostical information on the value type.
Sourceimpl<'a> UnsafeFromValue for &'a Response
impl<'a> UnsafeFromValue for &'a Response
Sourcetype Guard = RawRefGuard
type Guard = RawRefGuard
The raw guard returned. Read more
Sourceunsafe fn unsafe_from_value(
value: ValuePtr,
vm: &mut Vm,
) -> Result<(Self, Self::Guard), StackError>
unsafe fn unsafe_from_value( value: ValuePtr, vm: &mut Vm, ) -> Result<(Self, Self::Guard), StackError>
Convert the given reference using unsafe assumptions to a value. Read more
Sourceimpl<'a> UnsafeFromValue for &'a mut Response
impl<'a> UnsafeFromValue for &'a mut Response
Sourcetype Guard = RawMutGuard
type Guard = RawMutGuard
The raw guard returned. Read more
Sourceunsafe fn unsafe_from_value(
value: ValuePtr,
vm: &mut Vm,
) -> Result<(Self, Self::Guard), StackError>
unsafe fn unsafe_from_value( value: ValuePtr, vm: &mut Vm, ) -> Result<(Self, Self::Guard), StackError>
Convert the given reference using unsafe assumptions to a value. Read more
Sourceimpl<'a> UnsafeToValue for &'a Response
impl<'a> UnsafeToValue for &'a Response
Sourceunsafe fn unsafe_to_value(self, vm: &mut Vm) -> Result<ValuePtr, StackError>
unsafe fn unsafe_to_value(self, vm: &mut Vm) -> Result<ValuePtr, StackError>
Convert into a value.
Sourceimpl<'a> UnsafeToValue for &'a mut Response
impl<'a> UnsafeToValue for &'a mut Response
Sourceunsafe fn unsafe_to_value(self, vm: &mut Vm) -> Result<ValuePtr, StackError>
unsafe fn unsafe_to_value(self, vm: &mut Vm) -> Result<ValuePtr, StackError>
Convert into a value.